# remirepo/Fedora spec file for php-doctrine-collections
#
# Copyright (c) 2013-2022 Shawn Iwinski, Remi Collet
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     doctrine
%global github_name      collections
%global github_version   2.0.1
%global github_commit    d766a450ba818dacc4b1f50a56cfaad4683cefef

%global composer_vendor  doctrine
%global composer_project collections

%global major            2

# "php": "^8.1"
%global php_min_ver 8.1
# "doctrine/deprecations": "^1"
%global doctrine_depr_min_ver 1
%global doctrine_depr_max_ver 2

# Build using "--without tests" to disable tests
%bcond_without tests

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}%{major}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Collections abstraction library, version %{major}

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}

# GitHub export does not include tests.
# Run php-doctrine-collections-get-source.sh to create full source.
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Tests
%if %{with tests}
## composer.json
%global phpunit %{_bindir}/phpunit9
BuildRequires: %{phpunit}
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-json
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(doctrine/deprecations) >= %{doctrine_depr_min_ver} with php-composer(doctrine/deprecations) < %{doctrine_depr_max_ver})
# remirepo:3
%else
BuildRequires: php-doctrine-deprecations
%endif
## phpcompatinfo (computed from version 2.0.0)
BuildRequires: php-pcre
BuildRequires: php-spl
%endif
# Autoloader
BuildRequires: php-fedora-autoloader-devel

# composer.json
Requires:      php(language) >= %{php_min_ver}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:     (php-composer(doctrine/deprecations) >= %{doctrine_depr_min_ver} with php-composer(doctrine/deprecations) < %{doctrine_depr_max_ver})
# remirepo:3
%else
Requires:      php-doctrine-deprecations
%endif
# phpcompatinfo (computed from version 2.0.0)
Requires:      php-pcre
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

# Extracted from Doctrine Common as of version 2.4
Conflicts:     php-pear(pear.doctrine-project.org/DoctrineCommon) < 2.4

%description
%{summary}.

Autoloader: %{phpdir}/Doctrine/Common/Collections/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
phpab --template fedora \
      --output src/autoload.php \
      src

cat <<'AUTOLOAD' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{phpdir}/Doctrine/Deprecations/autoload.php',
]);
AUTOLOAD


%install
mkdir -p   %{buildroot}%{phpdir}/Doctrine/Common/
cp -rp src %{buildroot}%{phpdir}/Doctrine/Common/Collections%{major}


%check
%if %{with tests}
: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Doctrine/Common/Collections%{major}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Doctrine\\Tests\\', __DIR__.'/tests');
BOOTSTRAP

: Upstream tests
SCL_RETURN_CODE=0
for CMD in "php %{phpunit}" php81 php82; do
    if which $CMD; then
        set $CMD
        $1 ${2:-%{_bindir}/phpunit9} --verbose --bootstrap bootstrap.php \
            || SCL_RETURN_CODE=1
    fi
done
exit $SCL_RETURN_CODE
%else
: Tests skipped
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%dir %{phpdir}/Doctrine
%dir %{phpdir}/Doctrine/Common
     %{phpdir}/Doctrine/Common/Collections%{major}


%changelog
* Fri Sep 30 2022 Remi Collet <remi@remirepo.net> - 2.0.1-1
- update to 2.0.1

* Fri Sep 30 2022 Remi Collet <remi@remirepo.net> - 2.0.0-1
- update to 2.0.0
- rename to php-doctrine-collections2
- install in /usr/share/php/Doctrine/Common/Collections2
- raise dependency on PHP 8.1

* Fri Sep 30 2022 Remi Collet <remi@remirepo.net> - 1.8.0-1
- update to 1.8.0

* Mon Sep 26 2022 Remi Collet <remi@remirepo.net> - 1.7.3-1
- update to 1.7.3

* Fri Sep  9 2022 Remi Collet <remi@remirepo.net> - 1.7.2-1
- update to 1.7.2
- switch to classmap autoloader
- add dependency on doctrine/deprecations

* Fri Sep  9 2022 Remi Collet <remi@remirepo.net> - 1.6.9-1
- update to 1.6.9

* Wed Aug 11 2021 Remi Collet <remi@remirepo.net> - 1.6.8-1
- update to 1.6.8

* Tue Aug 11 2020 Remi Collet <remi@remirepo.net> - 1.6.7-1
- update to 1.6.7
- add upstream patch for recent PHPUnit

* Mon Jul 20 2020 Remi Collet <remi@remirepo.net> - 1.6.6-1
- update to 1.6.6

* Tue May 26 2020 Remi Collet <remi@remirepo.net> - 1.6.5-1
- update to 1.6.5

* Wed Nov 13 2019 Remi Collet <remi@remirepo.net> - 1.6.4-1
- update to 1.6.4

* Tue Jun 11 2019 Remi Collet <remi@remirepo.net> - 1.6.2-1
- update to 1.6.2

* Tue Mar 26 2019 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1

* Mon Mar 25 2019 Remi Collet <remi@remirepo.net> - 1.6.0-1
- update to 1.6.0
- raise dependency on PHP 7.1.3
- use PHPUnit 7 for test suite

* Sat Mar 04 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.4.0-1
- Updated to 1.4.0 (RHBZ #1415530)
- Switched autoloader to php-composer(fedora/autoloader)

* Sat Jun 27 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.3.0-3
- Updated autoloader with trailing separator

* Wed Jun 24 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.3.0-2
- Added autoloader dependencies

* Wed Jun 24 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.3.0-1
- Updated to 1.3.0 (RHBZ #1211818)
- Added autoloader
- %%license usage

* Fri Jun 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2-3
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide
- Added option to build without tests ("--without tests")

* Mon Feb 17 2014 Remi Collet <rpms@famillecollet.com> 1.2-1
- backport 1.2 for remi repo

* Wed Feb 12 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.2-1
- Updated to 1.2 (BZ #1061117)

* Sat Jan 11 2014 Remi Collet <rpms@famillecollet.com> 1.1-3.20131221git8198717
- backport for remi repo

* Mon Jan 06 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1-3.20131221git8198717
- Minor syntax changes

* Fri Jan 03 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1-2.20131221git8198717
- Conditional %%{?dist}
- Added conflict w/ PEAR-based DoctrineCommon pkg (version < 2.4)

* Mon Dec 23 2013 Shawn Iwinski <shawn.iwinski@gmail.com> 1.1-1.20131221git8198717
- Initial package
